@@ -1,5 +1,5 @@
 """
-# [labml.ai Neural Networks](index.html)
+# [labml.ai Annotated PyTorch Paper Implementations](index.html)
 
 This is a collection of simple PyTorch implementations of
 neural networks and related algorithms.
@@ -36,9 +36,10 @@ implementations.
 #### ✨ [Capsule Networks](capsule_networks/index.html)
 
 #### ✨ [Generative Adversarial Networks](gan/index.html)
-* [GAN with a multi-layer perceptron](gan/simple_mnist_experiment.html)
-* [GAN with deep convolutional network](gan/dcgan.html)
-* [Cycle GAN](gan/cycle_gan.html)
+* [Original GAN](gan/original/index.html)
+* [GAN with deep convolutional network](gan/dcgan/index.html)
+* [Cycle GAN](gan/cycle_gan/index.html)
+* [Wasserstein GAN](gan/wasserstein/index.html)
 
 #### ✨ [Sketch RNN](sketch_rnn/index.html)
 
@@ -63,6 +64,8 @@ implementations.
 * [Layer Normalization](https://nn.labml.ai/normalization/layer_norm/index.html)
 * [Instance Normalization](https://nn.labml.ai/normalization/instance_norm/index.html)
 * [Group Normalization](https://nn.labml.ai/normalization/group_norm/index.html)
+* [Weight Standardization](https://nn.labml.ai/normalization/weight_standardization/index.html)
+* [Batch-Channel Normalization](https://nn.labml.ai/normalization/batch_channel_norm/index.html)
 
 ### Installation
 
