@@ -1,8 +1,10 @@
 import torch
 from torch import nn
 
+from labml_helpers.module import Module
 
-class Swish(nn.Module):
+
+class Swish(Module):
     def __init__(self):
         super().__init__()
         self.sigmoid = nn.Sigmoid()
