@@ -11,4 +11,6 @@ summary: >
 * [Layer Normalization](layer_norm/index.html)
 * [Instance Normalization](instance_norm/index.html)
 * [Group Normalization](group_norm/index.html)
+* [Weight Standardization](weight_standardization/index.html)
+* [Batch-Channel Normalization](batch_channel_norm/index.html)
 """
