@@ -13,8 +13,9 @@ Our implementation only has a few million parameters and doesn't do model parall
 It does single GPU training, but we implement the concept of switching as described in the paper.
 
 The Switch Transformer uses different parameters for each token by switching among parameters
-based on the token. Thererfore, only a fraction of parameters are chosen for each token. So you
-can have more parameters but less computational cost.
+based on the token.
+Therefore, only a fraction of parameters are chosen for each token.
+So you can have more parameters but less computational cost.
 
 The switching happens at the Position-wise Feedforward network (FFN) of each transformer block.
 Position-wise feedforward network consists of two sequentially fully connected layers.
@@ -33,7 +34,7 @@ discusses dropping tokens when routing is not balanced.
 Here's [the training code](experiment.html) and a notebook for training a switch transformer on Tiny Shakespeare dataset.
 
 [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/lab-ml/nn/blob/master/labml_nn/transformers/switch/experiment.ipynb)
-[![View Run](https://img.shields.io/badge/labml-experiment-brightgreen)](https://web.lab-ml.com/run?uuid=c4656c605b9311eba13d0242ac1c0002)
+[![View Run](https://img.shields.io/badge/labml-experiment-brightgreen)](https://app.labml.ai/run/c4656c605b9311eba13d0242ac1c0002)
 """
 
 import torch
